@@ -1,13 +1,13 @@
 use libc::c_int;
 use object::*;
 
+#[cfg_attr(windows, link(name = "pythonXY"))]
 extern "C" {
     pub static mut PySeqIter_Type: PyTypeObject;
     pub static mut PyCallIter_Type: PyTypeObject;
 
     pub fn PySeqIter_New(arg1: *mut PyObject) -> *mut PyObject;
-    pub fn PyCallIter_New(arg1: *mut PyObject, arg2: *mut PyObject)
-     -> *mut PyObject;
+    pub fn PyCallIter_New(arg1: *mut PyObject, arg2: *mut PyObject) -> *mut PyObject;
 }
 
 #[inline(always)]
@@ -19,5 +19,3 @@ pub unsafe fn PySeqIter_Check(op: *mut PyObject) -> c_int {
 pub unsafe fn PyCallIter_Check(op: *mut PyObject) -> c_int {
     (Py_TYPE(op) == &mut PyCallIter_Type) as c_int
 }
-
-
