@@ -1,28 +1,34 @@
 use libc::{c_char, c_int, c_void};
-use pyport::Py_ssize_t;
-use object::*;
 use methodobject::PyMethodDef;
+use object::*;
+use pyport::Py_ssize_t;
 
-#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
+#[cfg_attr(windows, link(name = "pythonXY"))]
+extern "C" {
     pub static mut PyModule_Type: PyTypeObject;
 }
 
 #[inline(always)]
-pub unsafe fn PyModule_Check(op : *mut PyObject) -> c_int {
+pub unsafe fn PyModule_Check(op: *mut PyObject) -> c_int {
     PyObject_TypeCheck(op, &mut PyModule_Type)
 }
 
 #[inline(always)]
-pub unsafe fn PyModule_CheckExact(op : *mut PyObject) -> c_int {
+pub unsafe fn PyModule_CheckExact(op: *mut PyObject) -> c_int {
     (Py_TYPE(op) == &mut PyModule_Type) as c_int
 }
 
-#[cfg_attr(windows, link(name="pythonXY"))] extern "C" {
+#[cfg_attr(windows, link(name = "pythonXY"))]
+extern "C" {
     pub fn PyModule_NewObject(name: *mut PyObject) -> *mut PyObject;
     pub fn PyModule_New(name: *const c_char) -> *mut PyObject;
     pub fn PyModule_GetDict(arg1: *mut PyObject) -> *mut PyObject;
     pub fn PyModule_GetNameObject(arg1: *mut PyObject) -> *mut PyObject;
     pub fn PyModule_GetName(arg1: *mut PyObject) -> *const c_char;
+    #[deprecated(
+        since = "0.3.1",
+        note = "Deprecated since Python 3.2; use PyModule_GetFilenameObject() instead"
+    )]
     pub fn PyModule_GetFilename(arg1: *mut PyObject) -> *const c_char;
     pub fn PyModule_GetFilenameObject(arg1: *mut PyObject) -> *mut PyObject;
     pub fn PyModule_GetDef(arg1: *mut PyObject) -> *mut PyModuleDef;
@@ -43,14 +49,16 @@ pub struct PyModuleDef_Base {
     pub m_copy: *mut PyObject,
 }
 impl Clone for PyModuleDef_Base {
-    fn clone(&self) -> PyModuleDef_Base { *self }
+    fn clone(&self) -> PyModuleDef_Base {
+        *self
+    }
 }
 
 pub const PyModuleDef_HEAD_INIT: PyModuleDef_Base = PyModuleDef_Base {
     ob_base: PyObject_HEAD_INIT,
     m_init: None,
     m_index: 0,
-    m_copy: 0 as *mut PyObject
+    m_copy: 0 as *mut PyObject,
 };
 
 #[repr(C)]
@@ -62,13 +70,15 @@ pub struct PyModuleDef_Slot {
 }
 #[cfg(Py_3_5)]
 impl Clone for PyModuleDef_Slot {
-    fn clone(&self) -> PyModuleDef_Slot { *self }
+    fn clone(&self) -> PyModuleDef_Slot {
+        *self
+    }
 }
 
 #[cfg(Py_3_5)]
-pub const Py_mod_create : c_int = 1;
+pub const Py_mod_create: c_int = 1;
 #[cfg(Py_3_5)]
-pub const Py_mod_exec : c_int = 2;
+pub const Py_mod_exec: c_int = 2;
 
 #[repr(C)]
 #[derive(Copy)]
@@ -87,7 +97,9 @@ pub struct PyModuleDef {
     pub m_free: Option<freefunc>,
 }
 impl Clone for PyModuleDef {
-    fn clone(&self) -> PyModuleDef { *self }
+    fn clone(&self) -> PyModuleDef {
+        *self
+    }
 }
 
 #[cfg(not(Py_3_5))]
@@ -100,7 +112,7 @@ pub const PyModuleDef_INIT: PyModuleDef = PyModuleDef {
     m_reload: None,
     m_traverse: None,
     m_clear: None,
-    m_free: None
+    m_free: None,
 };
 
 #[cfg(Py_3_5)]
@@ -113,5 +125,5 @@ pub const PyModuleDef_INIT: PyModuleDef = PyModuleDef {
     m_slots: 0 as *mut _,
     m_traverse: None,
     m_clear: None,
-    m_free: None
+    m_free: None,
 };
